==> kafka-3.9.0-src.tgz: kafka-3.9.0-src/streams/src/main/java/org/apache/kafka/streams/processor/BatchingStateRestoreCallback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.streams.processor;


import org.apache.kafka.streams.KeyValue;

import java.util.Collection;

/**
 * Interface for batching restoration of a {@link StateStore}
 *
 * It is expected that implementations of this class will not call the {@link StateRestoreCallback#restore(byte[],
 * byte[])} method.
 */
public interface BatchingStateRestoreCallback extends StateRestoreCallback {

    /**
     * Called to restore a number of records.  This method is called repeatedly until the {@link StateStore} is fulled
     * restored.
     *
     * @param records the records to restore.
     */
    void restoreAll(Collection<KeyValue<byte[], byte[]>> records);

    @Override
    default void restore(byte[] key, byte[] value) {
        throw new UnsupportedOperationException();
    }
}

==> kafka-4.1.0-src.tgz: kafka-4.1.0-src/streams/src/main/java/org/apache/kafka/streams/processor/BatchingStateRestoreCallback.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.streams.processor;


import org.apache.kafka.streams.KeyValue;

import java.util.Collection;

/**
 * Interface for batching restoration of a {@link StateStore}
 *
 * It is expected that implementations of this class will not call the {@link StateRestoreCallback#restore(byte[],
 * byte[])} method.
 */
public interface BatchingStateRestoreCallback extends StateRestoreCallback {

    /**
     * Called to restore a number of records. This method is called repeatedly until the {@link StateStore} is fully
     * restored.
     *
     * @param records the records to restore.
     */
    void restoreAll(Collection<KeyValue<byte[], byte[]>> records);

    @Override
    default void restore(byte[] key, byte[] value) {
        throw new UnsupportedOperationException();
    }
}
